@@ -1,27 +1,37 @@
 from peek_plugin_base.agent.PluginAgentEntryHookABC import PluginAgentEntryHookABC
-from peek_plugin_base.server.PluginServerEntryHookABC import PluginServerEntryHookABC
+from peek_plugin_base.server.PluginLogicEntryHookABC import PluginLogicEntryHookABC
 from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
 from peek_plugin_base.worker.PluginWorkerEntryHookABC import PluginWorkerEntryHookABC
 from typing import Type
 
-__version__ = '2.5.6'
+__version__ = '3.1.5'
 
 
-def peekServerEntryHook() -> Type[PluginServerEntryHookABC]:
-    from ._private.server.ServerEntryHook import ServerEntryHook
-    return ServerEntryHook
+def peekLogicEntryHook() -> Type[PluginLogicEntryHookABC]:
+    from ._private.server.LogicEntryHook import LogicEntryHook
+
+    return LogicEntryHook
 
 
-def peekClientEntryHook() -> Type[PluginClientEntryHookABC]:
+def peekOfficeEntryHook() -> Type[PluginClientEntryHookABC]:
     from ._private.client.ClientEntryHook import ClientEntryHook
+
+    return ClientEntryHook
+
+
+def peekFieldEntryHook() -> Type[PluginClientEntryHookABC]:
+    from ._private.client.ClientEntryHook import ClientEntryHook
+
     return ClientEntryHook
 
 
 def peekWorkerEntryHook() -> Type[PluginWorkerEntryHookABC]:
     from ._private.worker.WorkerEntryHook import WorkerEntryHook
+
     return WorkerEntryHook
 
 
 def peekAgentEntryHook() -> Type[PluginAgentEntryHookABC]:
     from ._private.agent.AgentEntryHook import AgentEntryHook
+
     return AgentEntryHook
